==> domain-2.11.0.tgz: package/lib/fetcher/FetcherInterceptor.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
/** @typedef {import('./InterceptableFetcherInterface').default} InterceptableFetcherInterface */
/** @implements {InterceptableFetcherInterface} */
var FetcherInterceptor = /*#__PURE__*/function () {
  /**
   * @param {object} deps
   * @param {FetcherInterface} deps.fetcher
   */
  function FetcherInterceptor(_ref) {
    var fetcher = _ref.fetcher;
    this._fetcher = void 0;
    this._fetcher = fetcher;
  }

  /**
   * Checks if the result contains a promise
   * @param {object} result
   * @returns
   */
  var _proto = FetcherInterceptor.prototype;
  _proto._isPromiseType = function _isPromiseType(result) {
    return typeof result === 'object' && 'then' in result;
  }

  /**
   * Replaces the original result with a promise to intercept exceptions
   * @param {object} deps
   * @param {object} deps.originalResult
   * @returns
   */;
  _proto._interceptResult = function _interceptResult(_ref2) {
    var _this = this;
    var originalResult = _ref2.originalResult;
    var result = originalResult;
    if (this._isPromiseType(result)) {
      result = new Promise(function (resolve, reject) {
        return _this._catchExceptions({
          resolve: resolve,
          reject: reject,
          originalResult: originalResult
        });
      });
    }
    return result;
  }

  /**
   * Catches exceptions on the original result and calls the error interceptor
   * @param {object} deps
   * @param {object} deps.originalResult
   * @param {object} deps.reject
   * @param {object} deps.resolve
   */;
  _proto._catchExceptions =
  /*#__PURE__*/
  function () {
    var _catchExceptions2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref3) {
      var originalResult, resolve, reject, response;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              originalResult = _ref3.originalResult, resolve = _ref3.resolve, reject = _ref3.reject;
              _context.prev = 1;
              _context.next = 4;
              return originalResult;
            case 4:
              response = _context.sent;
              resolve(response);
              _context.next = 12;
              break;
            case 8:
              _context.prev = 8;
              _context.t0 = _context["catch"](1);
              if (FetcherInterceptor.errorInterceptor !== null && typeof FetcherInterceptor.errorInterceptor === 'function') {
                FetcherInterceptor.errorInterceptor(_context.t0);
              }
              reject(_context.t0);
            case 12:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, null, [[1, 8]]);
    }));
    function _catchExceptions(_x) {
      return _catchExceptions2.apply(this, arguments);
    }
    return _catchExceptions;
  }()
  /**
   * Defines the function to be called when an error is intercepted
   * @param {object} deps
   * @param {object} deps.callback
   * @returns
   */
  ;
  _proto.setErrorInterceptor = function setErrorInterceptor(_ref4) {
    var callback = _ref4.callback;
    FetcherInterceptor.errorInterceptor = callback;
  }

  /**
   * Unsets the function called when an error is intercepted
   */;
  _proto.unsetErrorInterceptor = function unsetErrorInterceptor() {
    FetcherInterceptor.errorInterceptor = null;
  }

  /**
   * Get method
   * @param {String} url
   * @param {Object} options
   * @return {Promise<any>}
   */;
  _proto.get = function get(url, options) {
    var originalResult = this._fetcher.get(url, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Post method
   * @method post
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Promise}
   */;
  _proto.post = function post(url, body, options) {
    var originalResult = this._fetcher.post(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Put method
   * @method put
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Object}
   */;
  _proto.put = function put(url, body, options) {
    var originalResult = this._fetcher.put(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Patch method
   * @method patch
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Object}
   */;
  _proto.patch = function patch(url, body, options) {
    var originalResult = this._fetcher.patch(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Delete method
   * @method delete
   * @param {String} url
   * @param {Object} options
   * @return {Object}
   */;
  _proto.delete = function _delete(url, options) {
    var originalResult = this._fetcher.delete(url, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  };
  return FetcherInterceptor;
}();
FetcherInterceptor.errorInterceptor = null;
export { FetcherInterceptor as default };

==> domain-2.12.0.tgz: package/lib/fetcher/FetcherInterceptor.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
/** @typedef {import('./InterceptableFetcherInterface').default} InterceptableFetcherInterface */
/** @implements {InterceptableFetcherInterface} */
var FetcherInterceptor = /*#__PURE__*/function () {
  /**
   * @param {object} deps
   * @param {FetcherInterface} deps.fetcher
   */
  function FetcherInterceptor(_ref) {
    var fetcher = _ref.fetcher;
    this._fetcher = void 0;
    this._fetcher = fetcher;
  }

  /**
   * Checks if the result contains a promise
   * @param {object} result
   * @returns
   */
  var _proto = FetcherInterceptor.prototype;
  _proto._isPromiseType = function _isPromiseType(result) {
    return typeof result === 'object' && 'then' in result;
  }

  /**
   * Replaces the original result with a promise to intercept exceptions
   * @param {object} deps
   * @param {object} deps.originalResult
   * @returns
   */;
  _proto._interceptResult = function _interceptResult(_ref2) {
    var _this = this;
    var originalResult = _ref2.originalResult;
    var result = originalResult;
    if (this._isPromiseType(result)) {
      result = new Promise(function (resolve, reject) {
        return _this._catchExceptions({
          resolve: resolve,
          reject: reject,
          originalResult: originalResult
        });
      });
    }
    return result;
  }

  /**
   * Catches exceptions on the original result and calls the error interceptor
   * @param {object} deps
   * @param {object} deps.originalResult
   * @param {object} deps.reject
   * @param {object} deps.resolve
   */;
  _proto._catchExceptions =
  /*#__PURE__*/
  function () {
    var _catchExceptions2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(_ref3) {
      var originalResult, resolve, reject, response;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            originalResult = _ref3.originalResult, resolve = _ref3.resolve, reject = _ref3.reject;
            _context.prev = 1;
            _context.next = 4;
            return originalResult;
          case 4:
            response = _context.sent;
            resolve(response);
            _context.next = 12;
            break;
          case 8:
            _context.prev = 8;
            _context.t0 = _context["catch"](1);
            if (FetcherInterceptor.errorInterceptor !== null && typeof FetcherInterceptor.errorInterceptor === 'function') {
              FetcherInterceptor.errorInterceptor(_context.t0);
            }
            reject(_context.t0);
          case 12:
          case "end":
            return _context.stop();
        }
      }, _callee, null, [[1, 8]]);
    }));
    function _catchExceptions(_x) {
      return _catchExceptions2.apply(this, arguments);
    }
    return _catchExceptions;
  }()
  /**
   * Defines the function to be called when an error is intercepted
   * @param {object} deps
   * @param {object} deps.callback
   * @returns
   */
  ;
  _proto.setErrorInterceptor = function setErrorInterceptor(_ref4) {
    var callback = _ref4.callback;
    FetcherInterceptor.errorInterceptor = callback;
  }

  /**
   * Unsets the function called when an error is intercepted
   */;
  _proto.unsetErrorInterceptor = function unsetErrorInterceptor() {
    FetcherInterceptor.errorInterceptor = null;
  }

  /**
   * Get method
   * @param {String} url
   * @param {Object} options
   * @return {Promise<any>}
   */;
  _proto.get = function get(url, options) {
    var originalResult = this._fetcher.get(url, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Post method
   * @method post
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Promise}
   */;
  _proto.post = function post(url, body, options) {
    var originalResult = this._fetcher.post(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Put method
   * @method put
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Object}
   */;
  _proto.put = function put(url, body, options) {
    var originalResult = this._fetcher.put(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Patch method
   * @method patch
   * @param {String} url
   * @param {String} body
   * @param {Object} options
   * @return {Object}
   */;
  _proto.patch = function patch(url, body, options) {
    var originalResult = this._fetcher.patch(url, body, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  }

  /**
   * Delete method
   * @method delete
   * @param {String} url
   * @param {Object} options
   * @return {Object}
   */;
  _proto.delete = function _delete(url, options) {
    var originalResult = this._fetcher.delete(url, options);
    var result = this._interceptResult({
      originalResult: originalResult
    });
    return result;
  };
  return FetcherInterceptor;
}();
FetcherInterceptor.errorInterceptor = null;
export { FetcherInterceptor as default };
